Class: Aws::Snowball::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Snowball::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-snowball/client.rb,
sig/client.rbs
Overview
An API client for Snowball. To construct a client, you need to configure a :region and :credentials.
client = Aws::Snowball::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelClusterResponseSuccess, _CancelJobResponseSuccess, _CreateAddressResponseSuccess, _CreateClusterResponseSuccess, _CreateJobResponseSuccess, _CreateLongTermPricingResponseSuccess, _CreateReturnShippingLabelResponseSuccess, _DescribeAddressResponseSuccess, _DescribeAddressesResponseSuccess, _DescribeClusterResponseSuccess, _DescribeJobResponseSuccess, _DescribeReturnShippingLabelResponseSuccess, _GetJobManifestResponseSuccess, _GetJobUnlockCodeResponseSuccess, _GetSnowballUsageResponseSuccess, _GetSoftwareUpdatesResponseSuccess, _ListClusterJobsResponseSuccess, _ListClustersResponseSuccess, _ListCompatibleImagesResponseSuccess, _ListJobsResponseSuccess, _ListLongTermPricingResponseSuccess, _ListPickupLocationsResponseSuccess, _ListServiceVersionsResponseSuccess, _UpdateClusterResponseSuccess, _UpdateJobResponseSuccess, _UpdateJobShipmentStateResponseSuccess, _UpdateLongTermPricingResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_cluster(params = {}) ⇒ Struct
Cancels a cluster job.
-
#cancel_job(params = {}) ⇒ Struct
Cancels the specified job.
-
#create_address(params = {}) ⇒ Types::CreateAddressResult
Creates an address for a Snow device to be shipped to.
-
#create_cluster(params = {}) ⇒ Types::CreateClusterResult
Creates an empty cluster.
-
#create_job(params = {}) ⇒ Types::CreateJobResult
Creates a job to import or export data between Amazon S3 and your on-premises data center.
-
#create_long_term_pricing(params = {}) ⇒ Types::CreateLongTermPricingResult
Creates a job with the long-term usage option for a device.
-
#create_return_shipping_label(params = {}) ⇒ Types::CreateReturnShippingLabelResult
Creates a shipping label that will be used to return the Snow device to Amazon Web Services.
-
#describe_address(params = {}) ⇒ Types::DescribeAddressResult
Takes an
AddressIdand returns specific details about that address in the form of anAddressobject. -
#describe_addresses(params = {}) ⇒ Types::DescribeAddressesResult
Returns a specified number of
ADDRESSobjects. -
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResult
Returns information about a specific cluster including shipping information, cluster status, and other important metadata.
-
#describe_job(params = {}) ⇒ Types::DescribeJobResult
Returns information about a specific job including shipping information, job status, and other important metadata.
-
#describe_return_shipping_label(params = {}) ⇒ Types::DescribeReturnShippingLabelResult
Information on the shipping label of a Snow device that is being returned to Amazon Web Services.
-
#get_job_manifest(params = {}) ⇒ Types::GetJobManifestResult
Returns a link to an Amazon S3 presigned URL for the manifest file associated with the specified
JobIdvalue. -
#get_job_unlock_code(params = {}) ⇒ Types::GetJobUnlockCodeResult
Returns the
UnlockCodecode value for the specified job. -
#get_snowball_usage(params = {}) ⇒ Types::GetSnowballUsageResult
Returns information about the Snow Family service limit for your account, and also the number of Snow devices your account has in use.
-
#get_software_updates(params = {}) ⇒ Types::GetSoftwareUpdatesResult
Returns an Amazon S3 presigned URL for an update file associated with a specified
JobId. -
#list_cluster_jobs(params = {}) ⇒ Types::ListClusterJobsResult
Returns an array of
JobListEntryobjects of the specified length. -
#list_clusters(params = {}) ⇒ Types::ListClustersResult
Returns an array of
ClusterListEntryobjects of the specified length. -
#list_compatible_images(params = {}) ⇒ Types::ListCompatibleImagesResult
This action returns a list of the different Amazon EC2-compatible Amazon Machine Images (AMIs) that are owned by your Amazon Web Services accountthat would be supported for use on a Snow device.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResult
Returns an array of
JobListEntryobjects of the specified length. -
#list_long_term_pricing(params = {}) ⇒ Types::ListLongTermPricingResult
Lists all long-term pricing types.
-
#list_pickup_locations(params = {}) ⇒ Types::ListPickupLocationsResult
A list of locations from which the customer can choose to pickup a device.
-
#list_service_versions(params = {}) ⇒ Types::ListServiceVersionsResult
Lists all supported versions for Snow on-device services.
-
#update_cluster(params = {}) ⇒ Struct
While a cluster's
ClusterStatevalue is in theAwaitingQuorumstate, you can update some of the information associated with a cluster. -
#update_job(params = {}) ⇒ Struct
While a job's
JobStatevalue isNew, you can update some of the information associated with a job. -
#update_job_shipment_state(params = {}) ⇒ Struct
Updates the state when a shipment state changes to a different state.
-
#update_long_term_pricing(params = {}) ⇒ Struct
Updates the long-term pricing type.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-snowball/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2988 2989 2990 |
# File 'lib/aws-sdk-snowball/client.rb', line 2988 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2991 2992 2993 |
# File 'lib/aws-sdk-snowball/client.rb', line 2991 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 |
# File 'lib/aws-sdk-snowball/client.rb', line 2961 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Snowball') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-snowball' context[:gem_version] = '1.105.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_cluster(params = {}) ⇒ Struct
Cancels a cluster job. You can only cancel a cluster job while it's
in the AwaitingQuorum status. You'll have at least an hour after
creating a cluster job to cancel it.
86 |
# File 'sig/client.rbs', line 86
def cancel_cluster: (
|
#cancel_job(params = {}) ⇒ Struct
Cancels the specified job. You can only cancel a job before its
JobState value changes to PreparingAppliance. Requesting the
ListJobs or DescribeJob action returns a job's JobState as part
of the response element data returned.
95 |
# File 'sig/client.rbs', line 95
def cancel_job: (
|
#create_address(params = {}) ⇒ Types::CreateAddressResult
Creates an address for a Snow device to be shipped to. In most
regions, addresses are validated at the time of creation. The address
you provide must be located within the serviceable area of your
region. If the address is invalid or unsupported, then an exception is
thrown. If providing an address as a JSON file through the
cli-input-json option, include the full file path. For example,
--cli-input-json file://create-address.json.
105 |
# File 'sig/client.rbs', line 105
def create_address: (
|
#create_cluster(params = {}) ⇒ Types::CreateClusterResult
Creates an empty cluster. Each cluster supports five nodes. You use the CreateJob action separately to create the jobs for each of these nodes. The cluster does not ship until these five node jobs have been created.
132 |
# File 'sig/client.rbs', line 132
def create_cluster: (
|
#create_job(params = {}) ⇒ Types::CreateJobResult
Creates a job to import or export data between Amazon S3 and your
on-premises data center. Your Amazon Web Services account must have
the right trust policies and permissions in place to create a job for
a Snow device. If you're creating a job for a node in a cluster, you
only need to provide the clusterId value; the other job attributes
are inherited from the cluster.
The device capacity is optional.
Availability of device types differ by Amazon Web Services Region. For more information about Region availability, see Amazon Web Services Regional Services.
Snow Family devices and their capacities.
-
Device type: SNC1_SSD
-
Capacity: T14
-
Description: Snowcone
-
Device type: SNC1_HDD
-
Capacity: T8
-
Description: Snowcone
-
Device type: EDGE_S
-
Capacity: T98
-
Description: Snowball Edge Storage Optimized for data transfer only
-
Device type: EDGE_CG
-
Capacity: T42
-
Description: Snowball Edge Compute Optimized with GPU
-
Device type: EDGE_C
-
Capacity: T42
-
Description: Snowball Edge Compute Optimized without GPU
-
Device type: EDGE
-
Capacity: T100
-
Description: Snowball Edge Storage Optimized with EC2 Compute
This device is replaced with T98.
-
Device type: STANDARD
-
Capacity: T50
-
Description: Original Snowball device
This device is only available in the Ningxia, Beijing, and Singapore Amazon Web Services Region -
Device type: STANDARD
-
Capacity: T80
-
Description: Original Snowball device
This device is only available in the Ningxia, Beijing, and Singapore Amazon Web Services Region. -
Snow Family device type: RACK_5U_C
-
Capacity: T13
-
Description: Snowblade.
-
Device type: V3_5S
-
Capacity: T240
-
Description: Snowball Edge Storage Optimized 210TB
167 |
# File 'sig/client.rbs', line 167
def create_job: (
|
#create_long_term_pricing(params = {}) ⇒ Types::CreateLongTermPricingResult
Creates a job with the long-term usage option for a device. The long-term usage is a 1-year or 3-year long-term pricing type for the device. You are billed upfront, and Amazon Web Services provides discounts for long-term pricing.
210 |
# File 'sig/client.rbs', line 210
def create_long_term_pricing: (
|
#create_return_shipping_label(params = {}) ⇒ Types::CreateReturnShippingLabelResult
Creates a shipping label that will be used to return the Snow device to Amazon Web Services.
222 |
# File 'sig/client.rbs', line 222
def create_return_shipping_label: (
|
#describe_address(params = {}) ⇒ Types::DescribeAddressResult
Takes an AddressId and returns specific details about that address
in the form of an Address object.
233 |
# File 'sig/client.rbs', line 233
def describe_address: (
|
#describe_addresses(params = {}) ⇒ Types::DescribeAddressesResult
Returns a specified number of ADDRESS objects. Calling this API in
one of the US regions will return addresses from the list of all
addresses associated with this account in all US regions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
244 |
# File 'sig/client.rbs', line 244
def describe_addresses: (
|
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResult
Returns information about a specific cluster including shipping information, cluster status, and other important metadata.
255 |
# File 'sig/client.rbs', line 255
def describe_cluster: (
|
#describe_job(params = {}) ⇒ Types::DescribeJobResult
Returns information about a specific job including shipping information, job status, and other important metadata.
266 |
# File 'sig/client.rbs', line 266
def describe_job: (
|
#describe_return_shipping_label(params = {}) ⇒ Types::DescribeReturnShippingLabelResult
Information on the shipping label of a Snow device that is being returned to Amazon Web Services.
278 |
# File 'sig/client.rbs', line 278
def describe_return_shipping_label: (
|
#get_job_manifest(params = {}) ⇒ Types::GetJobManifestResult
Returns a link to an Amazon S3 presigned URL for the manifest file
associated with the specified JobId value. You can access the
manifest file for up to 60 minutes after this request has been made.
To access the manifest file after 60 minutes have passed, you'll have
to make another call to the GetJobManifest action.
The manifest is an encrypted file that you can download after your job
enters the WithCustomer status. This is the only valid status for
calling this API as the manifest and UnlockCode code value are used
for securing your device and should only be used when you have the
device. The manifest is decrypted by using the UnlockCode code
value, when you pass both values to the Snow device through the
Snowball client when the client is started for the first time.
As a best practice, we recommend that you don't save a copy of an
UnlockCode value in the same location as the manifest file for that
job. Saving these separately helps prevent unauthorized parties from
gaining access to the Snow device associated with that job.
The credentials of a given job, including its manifest file and unlock code, expire 360 days after the job is created.
288 |
# File 'sig/client.rbs', line 288
def get_job_manifest: (
|
#get_job_unlock_code(params = {}) ⇒ Types::GetJobUnlockCodeResult
Returns the UnlockCode code value for the specified job. A
particular UnlockCode value can be accessed for up to 360 days after
the associated job has been created.
The UnlockCode value is a 29-character code with 25 alphanumeric
characters and 4 hyphens. This code is used to decrypt the manifest
file when it is passed along with the manifest to the Snow device
through the Snowball client when the client is started for the first
time. The only valid status for calling this API is WithCustomer as
the manifest and Unlock code values are used for securing your
device and should only be used when you have the device.
As a best practice, we recommend that you don't save a copy of the
UnlockCode in the same location as the manifest file for that job.
Saving these separately helps prevent unauthorized parties from
gaining access to the Snow device associated with that job.
298 |
# File 'sig/client.rbs', line 298
def get_job_unlock_code: (
|
#get_snowball_usage(params = {}) ⇒ Types::GetSnowballUsageResult
Returns information about the Snow Family service limit for your account, and also the number of Snow devices your account has in use.
The default service limit for the number of Snow devices that you can have at one time is 1. If you want to increase your service limit, contact Amazon Web Services Support.
309 |
# File 'sig/client.rbs', line 309
def get_snowball_usage: (
|
#get_software_updates(params = {}) ⇒ Types::GetSoftwareUpdatesResult
Returns an Amazon S3 presigned URL for an update file associated with
a specified JobId.
318 |
# File 'sig/client.rbs', line 318
def get_software_updates: (
|
#list_cluster_jobs(params = {}) ⇒ Types::ListClusterJobsResult
Returns an array of JobListEntry objects of the specified length.
Each JobListEntry object is for a job in the specified cluster and
contains a job's state, a job's ID, and other information.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
329 |
# File 'sig/client.rbs', line 329
def list_cluster_jobs: (
|
#list_clusters(params = {}) ⇒ Types::ListClustersResult
Returns an array of ClusterListEntry objects of the specified
length. Each ClusterListEntry object contains a cluster's state, a
cluster's ID, and other important status information.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
342 |
# File 'sig/client.rbs', line 342
def list_clusters: (
|
#list_compatible_images(params = {}) ⇒ Types::ListCompatibleImagesResult
This action returns a list of the different Amazon EC2-compatible Amazon Machine Images (AMIs) that are owned by your Amazon Web Services accountthat would be supported for use on a Snow device. Currently, supported AMIs are based on the Amazon Linux-2, Ubuntu 20.04 LTS - Focal, or Ubuntu 22.04 LTS - Jammy images, available on the Amazon Web Services Marketplace. Ubuntu 16.04 LTS - Xenial (HVM) images are no longer supported in the Market, but still supported for use on devices through Amazon EC2 VM Import/Export and running locally in AMIs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
354 |
# File 'sig/client.rbs', line 354
def list_compatible_images: (
|
#list_jobs(params = {}) ⇒ Types::ListJobsResult
Returns an array of JobListEntry objects of the specified length.
Each JobListEntry object contains a job's state, a job's ID, and a
value that indicates whether the job is a job part, in the case of
export jobs. Calling this API action in one of the US regions will
return jobs from the list of all jobs associated with this account in
all US regions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
366 |
# File 'sig/client.rbs', line 366
def list_jobs: (
|
#list_long_term_pricing(params = {}) ⇒ Types::ListLongTermPricingResult
Lists all long-term pricing types.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
378 |
# File 'sig/client.rbs', line 378
def list_long_term_pricing: (
|
#list_pickup_locations(params = {}) ⇒ Types::ListPickupLocationsResult
A list of locations from which the customer can choose to pickup a device.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
390 |
# File 'sig/client.rbs', line 390
def list_pickup_locations: (
|
#list_service_versions(params = {}) ⇒ Types::ListServiceVersionsResult
Lists all supported versions for Snow on-device services. Returns an
array of ServiceVersion object containing the supported versions for
a particular service.
404 |
# File 'sig/client.rbs', line 404
def list_service_versions: (
|
#update_cluster(params = {}) ⇒ Struct
While a cluster's ClusterState value is in the AwaitingQuorum
state, you can update some of the information associated with a
cluster. Once the cluster changes to a different job state, usually 60
minutes after the cluster being created, this action is no longer
available.
423 |
# File 'sig/client.rbs', line 423
def update_cluster: (
|
#update_job(params = {}) ⇒ Struct
While a job's JobState value is New, you can update some of the
information associated with a job. Once the job changes to a different
job state, usually within 60 minutes of the job being created, this
action is no longer available.
445 |
# File 'sig/client.rbs', line 445
def update_job: (
|
#update_job_shipment_state(params = {}) ⇒ Struct
Updates the state when a shipment state changes to a different state.
469 |
# File 'sig/client.rbs', line 469
def update_job_shipment_state: (
|
#update_long_term_pricing(params = {}) ⇒ Struct
Updates the long-term pricing type.
479 |
# File 'sig/client.rbs', line 479
def update_long_term_pricing: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2981 2982 2983 |
# File 'lib/aws-sdk-snowball/client.rb', line 2981 def waiter_names [] end |