Class: Aws::Snowball::Types::ListJobsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Snowball::Types::ListJobsResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-snowball/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_list_entries ⇒ Array<Types::JobListEntry>
Each
JobListEntryobject contains a job's state, a job's ID, and a value that indicates whether the job is a job part, in the case of export jobs. -
#next_token ⇒ String
HTTP requests are stateless.
Instance Attribute Details
#job_list_entries ⇒ Array<Types::JobListEntry>
Each JobListEntry object contains a job's state, a job's ID, and
a value that indicates whether the job is a job part, in the case of
export jobs.
1889 1890 1891 1892 1893 1894 |
# File 'lib/aws-sdk-snowball/types.rb', line 1889 class ListJobsResult < Struct.new( :job_list_entries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
HTTP requests are stateless. If you use this automatically generated
NextToken value in your next ListJobs call, your returned
JobListEntry objects will start from this point in the array.
1889 1890 1891 1892 1893 1894 |
# File 'lib/aws-sdk-snowball/types.rb', line 1889 class ListJobsResult < Struct.new( :job_list_entries, :next_token) SENSITIVE = [] include Aws::Structure end |