Class: Aws::Snowball::Types::Notification
- Inherits:
-
Struct
- Object
- Struct
- Aws::Snowball::Types::Notification
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-snowball/types.rb
Overview
The Amazon Simple Notification Service (Amazon SNS) notification settings associated with a specific job. The Notification object is returned as a part of the response syntax of the DescribeJob action in the JobMetadata data type.
When the notification settings are defined during job creation, you can choose to notify based on a specific set of job states using the JobStatesToNotify array of strings, or you can specify that you want to have Amazon SNS notifications sent out for all job states with NotifyAll set to true.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device_pickup_sns_topic_arn ⇒ String
Used to send SNS notifications for the person picking up the device (identified during job creation).
-
#job_states_to_notify ⇒ Array<String>
The list of job states that will trigger a notification for this job.
-
#notify_all ⇒ Boolean
Any change in job state will trigger a notification for this job.
-
#sns_topic_arn ⇒ String
The new SNS
TopicArnthat you want to associate with this job.
Instance Attribute Details
#device_pickup_sns_topic_arn ⇒ String
Used to send SNS notifications for the person picking up the device (identified during job creation).
2164 2165 2166 2167 2168 2169 2170 2171 |
# File 'lib/aws-sdk-snowball/types.rb', line 2164 class Notification < Struct.new( :sns_topic_arn, :job_states_to_notify, :notify_all, :device_pickup_sns_topic_arn) SENSITIVE = [] include Aws::Structure end |
#job_states_to_notify ⇒ Array<String>
The list of job states that will trigger a notification for this job.
2164 2165 2166 2167 2168 2169 2170 2171 |
# File 'lib/aws-sdk-snowball/types.rb', line 2164 class Notification < Struct.new( :sns_topic_arn, :job_states_to_notify, :notify_all, :device_pickup_sns_topic_arn) SENSITIVE = [] include Aws::Structure end |
#notify_all ⇒ Boolean
Any change in job state will trigger a notification for this job.
2164 2165 2166 2167 2168 2169 2170 2171 |
# File 'lib/aws-sdk-snowball/types.rb', line 2164 class Notification < Struct.new( :sns_topic_arn, :job_states_to_notify, :notify_all, :device_pickup_sns_topic_arn) SENSITIVE = [] include Aws::Structure end |
#sns_topic_arn ⇒ String
The new SNS TopicArn that you want to associate with this job. You can create Amazon Resource Names (ARNs) for topics by using the
- CreateTopic][1
-
Amazon SNS API action.
You can subscribe email addresses to an Amazon SNS topic through the Amazon Web Services Management Console, or by using the
- Subscribe][2
-
Amazon Simple Notification Service (Amazon SNS) API
action.
[1]: docs.aws.amazon.com/sns/latest/api/API_CreateTopic.html [2]: docs.aws.amazon.com/sns/latest/api/API_Subscribe.html
2164 2165 2166 2167 2168 2169 2170 2171 |
# File 'lib/aws-sdk-snowball/types.rb', line 2164 class Notification < Struct.new( :sns_topic_arn, :job_states_to_notify, :notify_all, :device_pickup_sns_topic_arn) SENSITIVE = [] include Aws::Structure end |